@@ -48,8 +48,6 @@ use warnings;
 
 Constructor.  Called when this plugin is instantiated.
 
-This merely saves away the name of our plugin.
-
 =end doc
 
 =cut
@@ -60,7 +58,6 @@ sub new
     my $class = ref($proto) || $proto;
 
     my $self = {};
-    $self->{ 'name' } = $proto;
 
     # verbose?
     $self->{ 'verbose' } = $supplied{ 'verbose' } || 0;
@@ -69,24 +66,6 @@ sub new
     return $self;
 }
 
-
-=begin doc
-
-Return the name of our plugin, as saved in the constructor.
-
-=end doc
-
-=cut
-
-sub name
-{
-    my ($self) = (@_);
-    return ( $self->{ 'name' } );
-}
-
-
-
-
 =begin doc
 
 Block posts that are only a few words long.
